function [alpha,points,points0,pointsneg,N,N0]=coefficients(T,tN,xN,xdist,c,n,beta)

% calculates the coefficients alpha of the approximation v
% reduced form
% T>0 and [-T,T] is the time interval
% tN denotes the number of steps in time direction from -T to 0
% xdist the distance in x-direction
% xN denotes the number of steps in positive x-direction
% c denotes the constant in the RBF
% n is the dimension

% points are the points (tau_k,x_k) in (0,T]\times R^n, N points
% pointsneg are the points with negative value
% points0 are the points in 0\times R^n, N0 points

% returns alpha, which is the N0+N coefficient vector


N=0;
for k=1:tN
    t=k*T/tN;
    for l=-xN:xN
        x=xdist*l;
        N=N+1;
        points(N,:)=[t,x];
        pointsneg(N,:)=[-t,x];
      end
end



% points0 are the points in 0\times R^n, N0 points TAKE OUT EQUILIBRIUM
% POINT!

N0=0;
for l=-xN:-1
     x=xdist*l;
        N0=N0+1;
        points0(N0,:)=[0,x];
end
for l=1:xN
     x=xdist*l;
        N0=N0+1;
        points0(N0,:)=[0,x];
end


% Definition of the matrix M

    
% A
for j=1:N0
    for k=1:N0
        diff=transpose(points0(j,:)-points0(k,:));
        r=norm(diff);
        M(j,k)=-phi2(r,c)*(F(points0(j,:),beta)*diff).*(F(points0(k,:),beta)*diff)-...        
                phi1(r,c)*(F(points0(j,:),beta)*F(points0(k,:),beta)');
    end
end

% B
for j=1:N0
    for k=1:N
        diff=transpose(points0(j,:)-points(k,:));
        r=norm(diff);
        M(j,N0+k)=-phi2(r,c)*(F(points0(j,:),beta)*diff).*(F(points(k,:),beta)*diff)-...        
                phi1(r,c)*(F(points0(j,:),beta)*F(points(k,:),beta)');
        diff=transpose(points0(j,:)-pointsneg(k,:));
        r=norm(diff);
        M(j,N0+k)=M(j,N0+k) -phi2(r,c)*(F(points0(j,:),beta)*diff).*(F(pointsneg(k,:),beta)*diff)-...        
                phi1(r,c)*(F(points0(j,:),beta)*F(pointsneg(k,:),beta)');
        M(N0+k,j)=M(j,N0+k);
    end
end



% D
for j=1:N
    for k=1:N
        diff=transpose(points(j,:)-points(k,:));
        r=norm(diff);
        M(N0+j,N0+k)=2*(-phi2(r,c)*(F(points(j,:),beta)*diff).*(F(points(k,:),beta)*diff)-...        
                phi1(r,c)*(F(points(j,:),beta)*F(points(k,:),beta)'));
        diff=transpose(pointsneg(j,:)-points(k,:));
        r=norm(diff);
        M(N0+j,N0+k)=M(N0+j,N0+k)+2*(-phi2(r,c)*(F(pointsneg(j,:),beta)*diff).*(F(points(k,:),beta)*diff)-...        
                phi1(r,c)*(F(pointsneg(j,:),beta)*F(points(k,:),beta)'));
        
    end
end



% RHS vector

for k=1:N0 
    m(k)=-norm(points0(k,:)).^2;
end

for k=1:N
    m(N0+k)=-2*norm(points(k,:)).^2;
end

% Solution of linear system

alpha=M\transpose(m);



